Distributions of cities
Species extinction
number of links in the www
firm sizes
Youtube views
books sold
academic citiations
floods
earthquakes
terrorist attacks


In contrast to:

height (at 5.9 > someone would be over 1 empire state tall)
10,0000 people taller than girraffes
and 180 million people less than 7 inches tall

When someone buys a Harry Potter book, she induces others to buy it

When a city increases in pop. it adds amenenities and job opportunities


The Matthew effect: "for mike" more begets more


Probabilty of an event is proportional to it's size raised to a negative exoponent

1/x describes a power law

In a power law: the probability of an event is inversely related to its size

the larger the event, the less likely it is to occur

THE EQUATION:

p(x) = C * x**(-a)

a has to be > 1, and determines the tail


Zipfs Law
when a = 2
the rank of an event times it's size equals a constant

Preferential attachment:
entities grow at rates relative to their proportions

A new arrival either joins an existing entity or creates a new one
If the latter, the probability of joining an existing entity is proporational to it's size

With probability p (small)
the arrival forms a new entity
with probability (1-p) the arrival joinns a new entity

In each setting an action (buying a book) increases the likelihood others will do the same

The implications of long tails:

long tails mean a few big winners and many losers as compared to a normal distribution


A person who writes a better book, a catchier song, should garner more sales

As our world becomes more interconnected, and feedbacks increase, we should see more long tails

The music lab study
